# Generated by Django 3.0.5 on 2020-04-18 22:20

from django.db import migrations, models
import django.db.models.deletion
import netbox_ddns.validators


class Migration(migrations.Migration):

    dependencies = [
        ('ipam', '0036_standardize_description'),
        ('netbox_ddns', '0004_ensure_trailing_dot'),
    ]

    operations = [
        migrations.CreateModel(
            name='ExtraDNSName',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False)),
                ('last_update', models.DateTimeField(auto_now=True)),
                ('forward_action', models.PositiveSmallIntegerField(blank=True, null=True)),
                ('forward_rcode', models.PositiveIntegerField(blank=True, null=True)),
                ('reverse_action', models.PositiveSmallIntegerField(blank=True, null=True)),
                ('reverse_rcode', models.PositiveIntegerField(blank=True, null=True)),
                ('name', models.CharField(max_length=255, validators=[netbox_ddns.validators.HostnameValidator()])),
                ('ip_address', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='ipam.IPAddress')),
            ],
            options={
                'verbose_name': 'extra DNS name',
                'verbose_name_plural': 'extra DNS names',
                'unique_together': {('ip_address', 'name')},
            },
        ),
    ]
